@@ -39,7 +39,7 @@ public slots:
     void requestRegistration();
     void checkLogin();
     void sendResultXml(QString category, double result);
-    void sendRouteXml();
+    void sendRouteXml(QString oldName, QString newName, int i);
     void requestTopList(QString category, QString limit);
     void requestCategories();
     void ackOfResult();
@@ -48,7 +48,10 @@ public slots:
     void ackOfCategories();
     void ackOfToplist();
     void ackOfLogin();
+    bool ackOfProfile();
+    void ackOfSendingPicture();
     void errorFromServer(QNetworkReply::NetworkError);
+    void sendProfileXml();
 
 };
 
