@@ -1,8 +1,8 @@
 /*
- * CarMainWindow main class
+ * Result dialog
  *
  * @author     Janne Änäkkälä <janne.anakkala@fudeco.com>
- * @author      Toni Jussila 	<toni.jussila@fudeco.com>
+ * @author     Toni Jussila 	<toni.jussila@fudeco.com>
  * @copyright  (c) 2010 Speed Freak team
  * @license    http://opensource.org/licenses/gpl-license.php GNU Public License
  */
@@ -13,6 +13,9 @@
 #include "math.h"
 #include <QPainter>
 #include <QPicture>
+#include <QDebug>
+#include <QDesktopServices>
+#include <QUrl>
 
 const int DIAGRAM_WIDTH = 400;
 const int DIAGRAM_HEIGHT = 300;
@@ -57,6 +60,9 @@ ResultDialog::ResultDialog(QWidget *parent) :
     ui(new Ui::ResultDialog)
 {
     ui->setupUi(this);
+
+    helpAccelerationDialog = NULL;
+
     timeAxelLength = 10;
     resultString = "";
     speedList << "0" << "10" << "20" << "30" << "40" << "50" << "60" << "70" << "80" << "90" << "100" ;
@@ -110,7 +116,15 @@ void ResultDialog::changeEvent(QEvent *e)
 void ResultDialog::paintEvent(QPaintEvent *)
 {
     setHeaders();
-    QPainter painter(this);
+    //Create Pixmap, where image will be draw
+    QPixmap image(ui->scrollArea->width(), ui->scrollArea->height()/*DIAGRAM_WIDTH+100, DIAGRAM_HEIGHT+70*/);
+	
+    //Create painter and give paramemeter where image will be draw
+    QPainter painter(&image);
+    painter.setPen(Qt::white);
+    painter.setBrush(Qt::white);
+    painter.drawRect(QRect(0, 0, ui->scrollArea->width(), ui->scrollArea->height()/*DIAGRAM_WIDTH+100, DIAGRAM_HEIGHT+70*/));
+    
 
     painter.setRenderHint(QPainter::Antialiasing, true);
     painter.setPen(QPen((Qt::gray),2));
@@ -122,7 +136,7 @@ void ResultDialog::paintEvent(QPaintEvent *)
 
     fontForResult.setPixelSize(50);
     painter.setFont(fontForResult);
-    painter.drawText(diagramStemStart.x() + 50, diagramStemStart.y() - 150, resultString);
+    painter.drawText(diagramStemStart.x() + 30, diagramStemStart.y() - 150, resultString);
     painter.setFont(font);
 
     painter.setPen(QPen((Qt::darkCyan),2));
@@ -194,6 +208,18 @@ void ResultDialog::paintEvent(QPaintEvent *)
     {
         painter.drawPolyline(points, pointsToShow);
     }
+    //Save image in file acceleration.png
+    image.save("acceleration.png", 0, -1);
+
+    //Create label
+    QLabel *imageLabel = new QLabel(this);
+    
+    //Set image pixmap to label
+    imageLabel->setPixmap(image);
+    
+    //Set image label to scrollArea
+    ui->scrollArea->setWidget(imageLabel);
+
 }
 
 /**
@@ -768,3 +794,38 @@ void ResultDialog::setSendServerButtonEnabled()
 {
     ui->pushButtonSend->setEnabled(true);
 }
+
+/**
+  * This slot function called when ever info button clicked.
+  */
+void ResultDialog::on_pushButtonInfo_clicked()
+{
+    if(!helpAccelerationDialog)
+    {
+        helpAccelerationDialog = new HelpAccelerationDialog;
+    }
+    connect(helpAccelerationDialog, SIGNAL(rejected()), this, SLOT(killHelpDialog()));
+    helpAccelerationDialog->show();
+}
+
+/**
+  * This slot function called when ever dialog rejected.
+  */
+void ResultDialog::killHelpDialog()
+{
+    if(helpAccelerationDialog)
+    {
+        qDebug() << "__Result kill: helpAccelerationDialog";
+        delete helpAccelerationDialog;
+        helpAccelerationDialog = NULL;
+    }
+}
+/**
+  * This slot function opens E-mail application with attachment file
+  * (acceleration.png). Image of resultdialog
+  */
+
+void ResultDialog::on_pushButtonEMail_clicked()
+{
+    QDesktopServices::openUrl(QUrl("mailto:name@domain.com?Subject=Acceleration Result&Body=Hi, Here are my acceleration result!&Attachment=acceleration.png"));
+}
