@@ -10,8 +10,9 @@
 #define SETTINGSDIALOG_H
 
 #include <QDialog>
-
 #include "instructionsdialog.h"
+#include <helpsettingsdialog.h>
+#include <profiledialog.h>
 
 namespace Ui {
     class SettingsDialog;
@@ -22,6 +23,8 @@ class SettingsDialog : public QDialog {
 public:
     SettingsDialog(QWidget *parent = 0);
     ~SettingsDialog();
+    HelpSettingsDialog *helpSettingsDialog;
+    ProfileDialog *profileDialog;
     void setRegUserName(QString username);
     void setRegPassword(QString password);
     void setRegEmail(QString email);
@@ -34,11 +37,13 @@ public:
     QString getPassword();
     void setLabelInfoToUser(QString infoText);
     void usernameOk(bool isOk);
+    void clearRegisterLineEdits();
 
 signals:
     void sendregistration();
     void userNameChanged();
     void logout();
+    void saveprofile();
 
 protected:
     void changeEvent(QEvent *e);
@@ -52,8 +57,12 @@ private:
     QString password;
 
 private slots:
+    void on_pushButtonProfile_clicked();
+    void on_pushButtonInfo_clicked();
     void on_setUserPushButton_clicked();
     void on_registratePushButton_clicked();
+    void killDialog();
+    void saveProfile();
 };
 
 #endif // SETTINGSDIALOG_H
